@@ -3,7 +3,7 @@
 # utility procs formerly in init.tcl dealing with auto execution
 # of commands and can be auto loaded themselves.
 #
-# RCS: @(#) $Id: auto.tcl,v 1.12.2.1 2004/11/16 16:56:01 dgp Exp $
+# RCS: @(#) $Id: auto.tcl,v 1.12.2.5 2005/01/27 22:26:17 dgp Exp $
 #
 # Copyright (c) 1991-1993 The Regents of the University of California.
 # Copyright (c) 1994-1998 Sun Microsystems, Inc.
@@ -16,26 +16,27 @@
 #
 # Destroy all cached information for auto-loading and auto-execution,
 # so that the information gets recomputed the next time it's needed.
-# Also delete any procedures that are listed in the auto-load index
-# except those defined in this file.
+# Also delete any procedures that are listed in the auto-load index,
+# except some of those defined in the Tcl script library.
 #
 # Arguments: 
 # None.
 
 proc auto_reset {} {
-    global auto_execs auto_index auto_oldpath
-    foreach p [info procs] {
-	if {[info exists auto_index($p)] && ![string match auto_* $p]
-		&& ([lsearch -exact {unknown pkg_mkIndex tclPkgSetup
-			tcl_findLibrary pkg_compareExtension
-			tclPkgUnknown tcl::MacOSXPkgUnknown
-			tcl::MacPkgUnknown} $p] < 0)} {
-	    rename $p {}
-	}
+    if {[array exists ::auto_index]} {
+        foreach cmdName [array names ::auto_index] {
+	    if {[string match auto_* $cmdName]} {continue}
+	    set fqcn [namespace which $cmdName]
+	    if {$fqcn eq ""} {continue}
+	    if {[catch {info args $fqcn}]} {continue}
+	    if {[lsearch -exact {
+		::unknown ::pkg_mkIndex ::tclPkgSetup ::tcl_findLibrary
+		::pkg_compareExtension ::tclPkgUnknown ::tcl::MacOSXPkgUnknown
+		::tcl::MacPkgUnknown} $fqcn] != -1} {continue}
+            rename $fqcn {}
+        }
     }
-    catch {unset auto_execs}
-    catch {unset auto_index}
-    catch {unset auto_oldpath}
+    unset -nocomplain ::auto_execs ::auto_index ::auto_oldpath
 }
 
 # tcl_findLibrary --
@@ -129,14 +130,24 @@ proc tcl_findLibrary {basename version patch initScript enVarName varName} {
     # uniquify $dirs in order
     array set seen {}
     foreach i $dirs {
-	if {[interp issafe]} {
+	# For Tcl 8.4.9, we've disabled the use of [file normalize] here.
+	# This means that two different path names that are the same path
+	# in normalized form, will both remain on the search path.  There
+	# should be no harm in that, just a bit more file system access
+	# than is strictly necessary.
+	#
+	# [file normalize] has been disabled because of reports it has
+	# caused difficulties with the freewrap utility.  To keep
+	# compatibility with freewrap's needs, we'll keep this disabled
+	# throughout the 8.4.x (x >= 9) releases.  See Bug 1072136.
+	if {1 || [interp issafe]} {
 	    set norm $i
 	} else {
 	    set norm [file normalize $i]
 	}
 	if {[info exists seen($norm)]} { continue }
 	set seen($norm) ""
-	lappend uniqdirs $norm
+	lappend uniqdirs $i
     }
     set dirs $uniqdirs
     foreach i $dirs {
